==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/ManagedRuleGroupOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property ruleGroupName Describes the managed rule group within the rule set to override
 * @property rules List of rules that will be enabled. If none specified, all rules in the group will be disabled.
 */
public data class ManagedRuleGroupOverrideArgs(
    public val ruleGroupName: Output<String>,
    public val rules: Output<List<ManagedRuleOverrideArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs =
        com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs.builder()
            .ruleGroupName(ruleGroupName.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedRuleGroupOverrideArgs].
 */
@PulumiTagMarker
public class ManagedRuleGroupOverrideArgsBuilder internal constructor() {
    private var ruleGroupName: Output<String>? = null

    private var rules: Output<List<ManagedRuleOverrideArgs>>? = null

    /**
     * @param value Describes the managed rule group within the rule set to override
     */
    @JvmName("fdtshpsephaajmje")
    public suspend fun ruleGroupName(`value`: Output<String>) {
        this.ruleGroupName = value
    }

    /**
     * @param value List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("ilhandhesptmnofs")
    public suspend fun rules(`value`: Output<List<ManagedRuleOverrideArgs>>) {
        this.rules = value
    }

    @JvmName("lalerkwdhbusilbu")
    public suspend fun rules(vararg values: Output<ManagedRuleOverrideArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("itwwjuvpbaburuje")
    public suspend fun rules(values: List<Output<ManagedRuleOverrideArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value Describes the managed rule group within the rule set to override
     */
    @JvmName("qekopveuxmlrnxxd")
    public suspend fun ruleGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupName = mapped
    }

    /**
     * @param value List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("lrmqmvwtmswmdndh")
    public suspend fun rules(`value`: List<ManagedRuleOverrideArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("wtgpyhwoigrmorux")
    public suspend fun rules(argument: List<suspend ManagedRuleOverrideArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("xhgsdminnvedkhwf")
    public suspend fun rules(vararg argument: suspend ManagedRuleOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ManagedRuleOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("aoabglmpuwrvdfrp")
    public suspend fun rules(argument: suspend ManagedRuleOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleOverrideArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("dlceitoauvcgyowt")
    public suspend fun rules(vararg values: ManagedRuleOverrideArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ManagedRuleGroupOverrideArgs = ManagedRuleGroupOverrideArgs(
        ruleGroupName = ruleGroupName ?: throw PulumiNullFieldException("ruleGroupName"),
        rules = rules,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/ManagedRuleGroupOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property ruleGroupName Describes the managed rule group within the rule set to override
 * @property rules List of rules that will be enabled. If none specified, all rules in the group will be disabled.
 */
public data class ManagedRuleGroupOverrideArgs(
    public val ruleGroupName: Output<String>,
    public val rules: Output<List<ManagedRuleOverrideArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs =
        com.pulumi.azurenative.cdn.inputs.ManagedRuleGroupOverrideArgs.builder()
            .ruleGroupName(ruleGroupName.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedRuleGroupOverrideArgs].
 */
@PulumiTagMarker
public class ManagedRuleGroupOverrideArgsBuilder internal constructor() {
    private var ruleGroupName: Output<String>? = null

    private var rules: Output<List<ManagedRuleOverrideArgs>>? = null

    /**
     * @param value Describes the managed rule group within the rule set to override
     */
    @JvmName("nswicycagypnuwhd")
    public suspend fun ruleGroupName(`value`: Output<String>) {
        this.ruleGroupName = value
    }

    /**
     * @param value List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("apsethheofoceaoa")
    public suspend fun rules(`value`: Output<List<ManagedRuleOverrideArgs>>) {
        this.rules = value
    }

    @JvmName("rxnlrxqcokkyqcai")
    public suspend fun rules(vararg values: Output<ManagedRuleOverrideArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("ovuwosihjblvijsf")
    public suspend fun rules(values: List<Output<ManagedRuleOverrideArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value Describes the managed rule group within the rule set to override
     */
    @JvmName("wyoasgyiucuongyi")
    public suspend fun ruleGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupName = mapped
    }

    /**
     * @param value List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("dkpcapogdqgphucq")
    public suspend fun rules(`value`: List<ManagedRuleOverrideArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("uukshxqmvllardfh")
    public suspend fun rules(argument: List<suspend ManagedRuleOverrideArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("verrolqekwyseicr")
    public suspend fun rules(vararg argument: suspend ManagedRuleOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ManagedRuleOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("yabvdstvugfkiauo")
    public suspend fun rules(argument: suspend ManagedRuleOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleOverrideArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values List of rules that will be enabled. If none specified, all rules in the group will be disabled.
     */
    @JvmName("cyxexkortqjnuxpr")
    public suspend fun rules(vararg values: ManagedRuleOverrideArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ManagedRuleGroupOverrideArgs = ManagedRuleGroupOverrideArgs(
        ruleGroupName = ruleGroupName ?: throw PulumiNullFieldException("ruleGroupName"),
        rules = rules,
    )
}
